==> fluxbox-0.9.14.tar.gz: fluxbox-0.9.14/nls/bg_BG/Translation.m <==
$ codeset=ISO-8859-1

$set 1 #Align

1   
2   
3   
4 
6   
7   
8   
11   
12   
13   
14   
15   
16   
17 

$set 2 #BaseDisplay


$set 3 #Common

2  

$set 4 #Configmenu

2  
4   
7       
8  
9   
10  
11 Image Dithering
12    
13  Sloppy 
14 Sloppy 
15 Workspace Warping

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 
4 
7 
9 
10 xterm

$set 11 #Remember


$set 12 #Screen

2 W: %4d x H: %4d
5 X: %4d x Y: %4d
6 0: 0000 x 0: 0000

$set 13 #Slit

4 Posoka na Slit -a
7   Slit -
8 Slit

$set 14 #Toolbar

1      
10   Toolbar -
11 Toolbar

$set 15 #Window

1 

$set 16 #Windowmenu

1 
2 
4 
5 
6 
7   ...
8 
9 

$set 17 #Workspace

1   %d
2  
3   
4  

$set 18 #fbsetroot

1 %s: error: must specify one of: -solid, -mod, -gradient\n
3 %s 2.0: (c) 1997-2000 Brad Hughes\n\n\
-display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 : '-display'  \n
11 : '-rc'  \n
12 Fluxkbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tuse display connection.\n\
-rc <string>\t\t\t   .\n\
-version\t\t\t   .\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\t     .\n\n

==> fluxbox_1.3.7.orig.tar.gz: fluxbox-1.3.7/nls/bg_BG/Translation.m <==
$ codeset=CP1251

$set 1 #Align

1   
2   
3   
4 
6   
7   
8   
11   
12   
13   
14   
15   
16   
17 

$set 2 #BaseDisplay


$set 3 #Common

2  

$set 4 #Configmenu

2  
4   
7       
8  
9   
10  
11 Image Dithering
12    
13  Sloppy 
14 Sloppy 
15 Workspace Warping

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 
4 
7 
9 

$set 11 #Remember


$set 12 #Screen

2 W: %4d x H: %4d
4 W: %04d x H: %04d

$set 13 #Slit

4 Posoka na Slit -a
7   Slit -
8 Slit

$set 14 #Toolbar

1      
10   Toolbar -
11 Toolbar

$set 15 #Window

1 

$set 16 #Windowmenu

1 
2 
4 
5 
6 
7   ...
8 
9 

$set 17 #Workspace

1   %d
2  
3   
4  

$set 18 #fbsetroot

1 error: must specify one of: -solid, -mod, -gradient\n
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 : '-display'  
11 : '-rc'  
13 Fluxkbox %s: (c) %s Fluxbox Team\n\n\
-display <string>\t\tuse display connection.\n\
-screen <all|int,int,int>\trun on specified screens only.\n\
-no-slit\t\t\tdo not provide a slit\n\
-no-toolbar\t\tdo not provide a toolbar\n\
-rc <string>\t\t\t   .\n\
-version\t\t\t   .\n\
-info\t\t\t\tdisplay some useful information.\n\
-list-commands\t\t\tlist all valid key commands.\n\
-sync\t\t\t\tsynchronize with X server for debugging.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\t     .\n\n
